Learn R Programming

amei (version 1.0-7)

getcost: Extract the Final Costs/Number of Vaccinations of the (Managed) Epidemic

Description

Extracts the (summary of the distribution of) final cost(s) or number of vaccinations performed of Monte Carlo epidemic under a static vaccination strategy as implemented by MCepi or a single adaptively managed epidemic as implemented by manage or MCmanage

Usage

getcost(obj) getvac(obj)

Arguments

obj
a object of class "MCepi", "epiman", or "MCmanage"

Value

The return value is a double-precision scalar indicating the median final cost obtained under manage, or a data.frame giving the median and quantiles calculated by MCepi or MCmanage

Details

getcost returns distribution information for the final (cumulative) costs of the (managed) epidemic, and getvac returns distribution information for the cumulative number of vaccinations performed. If x is if class "epiman" then the single final cost or number of vaccinations is performed is returned. For further details of this function please see the documentation for MCepi and manage

References

D. Merl, L.R. Johnson, R.B. Gramacy, and M.S. Mangel (2010). “amei: An R Package for the Adaptive Management of Epidemiological Interventions”. Journal of Statistical Software 36(6), 1-32. http://www.jstatsoft.org/v36/i06/ D. Merl, L.R. Johnson, R.B. Gramacy, M.S. Mangel (2009). “A Statistical Framework for the Adaptive Management of Epidemiological Interventions”. PLoS ONE, 4(6), e5807. http://www.plosone.org/article/info:doi/10.1371/journal.pone.0005807

See Also

MCepi, manage, MCmanage

Examples

Run this code
## for an example of the usage of this function,
## please see the documentation for MCepi as
## referenced in the See Also section, above

Run the code above in your browser using DataLab