Learn R Programming

amei (version 1.0-7)

getpolicy: Extract The Optimal Static Vaccination Policy

Description

Extracts the optimal static vaccination policy from an "optvac"-class object

Usage

getpolicy(obj, which = c("best", "worst"))

Arguments

obj
and "optvac"-class object
which
optionally, by supplying which = "worst" the worst static vaccination policy can be extracted

Value

The output is a data.frame with scalar entries
row
the row of vacgrid$stops from the "optvac"-class object corresponding to the lowest (or highest) cost
col
the row of vacgrid$fracs from the "optvac"-class object corresponding to the lowest (or highest) cost
frac
the actual optimal fraction to vaccinate from the vacgrid table
stop
the actual optimal (stopping) threshold from the vacgrid table
cost
the cost associated with the optimal static vaccination strategy

Details

This function is designed to work with the output of the optvac function, and to provide inputs to the MCepi function. It searches the cost grid defined by vacgrid for the lowest (or highest) cost, and returns this information

References

D. Merl, L.R. Johnson, R.B. Gramacy, and M.S. Mangel (2010). “amei: An R Package for the Adaptive Management of Epidemiological Interventions”. Journal of Statistical Software 36(6), 1-32. http://www.jstatsoft.org/v36/i06/ D. Merl, L.R. Johnson, R.B. Gramacy, M.S. Mangel (2009). “A Statistical Framework for the Adaptive Management of Epidemiological Interventions”. PLoS ONE, 4(6), e5807. http://www.plosone.org/article/info:doi/10.1371/journal.pone.0005807

See Also

optvac, plot.optvac, MCepi

Examples

Run this code
## for an example of the usage of this function,
## please see the documentation for optvac as
## referenced in the See Also section, above

Run the code above in your browser using DataLab