Usage
manage(init, epistep, vacgrid, costs, T = 40, Tstop = T, pinit = list(b = 0.1, k = 0.02, nu = 0.2, mu = 0.1), hyper = list(bh = c(1,3), kh = c(1,3), nuh = c(1,1), muh = c(1,1)), vac0=list(frac=0, stop=0), MCvits = 10, MCMCpits = 1000, bkrate = 1, vacsamps = 100, start = 8, ...)
Arguments
init
a list containing scalar entries $S0,
$I0, $R0, $D0 depicting the initial number of
susceptibles, infecteds, recovereds, and dead individuals in the
outbreak; an "epiman" object may also be provided in order
to continue managing an ongoing epidemic (see Details)
epistep
a function which moves the epidemic ahead one
time-step; see epistep T
the long-term horizon used to calculate optimal
vaccination strategies
Tstop
the maximum number of time steps during which the epidemic
is allowed to evolve; default is identical to T
vacgrid
a list containing vector entries $fracs and
$stops indicating the permissible fractions (in [0,1])
of the population to be vaccinated and the (positive integer) of
stopping thresholds having a maximum of init$S0; can be
NULL, see details below
costs
a list containing scalar entries $vac,
$death and $infect depicting the costs associated
with a single vaccination or death, or the daily cost of maintaining
an infected individual, respectively; can be NULL, but only
when vacgrid = NULL also
pinit
a list containing scalar entries
$b, $k, $nu, and $mu depicting the
initial values of parameters of the SIR model representing
the transmission probability, clumpiness parameter,
the recovery probability, and the mortality probability, respectively,
which are subsequently sampled by MCMC from the posterior
hyper
a list containing 2-vector entries describing
parameters to the prior distribution of the parameters listed in
the pinit argument. The prior for b follows
a gamma distribution with parameters $$bh$ where
the shape is given by bh[1] and scale by bh[2].
The prior for k specified by parameters $kh is similar.
The prior(s) for nu and
mu are specified through $p_r$ and $p_d$,
respectively, which follow Beta distributions and the default
specification is uniform. See vignette("amei") for more
details
vac0
the initial (static) vaccination policy to be used
before estimation of parameters begins (at start).
This is a list with scalar entries $frac
and $stop depicting the fraction to be vaccinated at each
time step, and the vaccination (stopping) threshold, respectively.
The default corresponds to no initial vaccination
MCvits
scalar number of Monte Carlo iterations of forward epidemic
evolution used at each time step to determine the optimal
vaccination policy
MCMCpits
scalar number of Markov chain Monte Carlo iterations used
at each step to estimate the SIR model parameters
bkrate
number of samples of b and k, relative
to mu and nu before a sample of all four parameters
is saved; this acknowledges that b and k are correlated
and thus mix slower than mu and nu
vacsamps
used to thin the MCMC samples of the parameters sampled
from the posterior that are used to calculate optimal vaccination policies;
this should be an integer scalar such that 0 < vacsamps <= mcmcpits<="" code=""> =>
start
at what time, after time 1 where the state is given
by init, should vaccinations be allowed to start
...
additional arguments passed to a user-defined
epistep function