Learn R Programming

amei (version 1.0-7)

print.Rd: Summarizing and printing amei output

Description

Summarizing, printing, and plotting the contents of a the following objects "MCepi", "optvac", "epiman". In the current version the printing and summary commands are very similar

Usage

"print"(x, ...) "print"(x, ...) "print"(x, ...) "summary"(object, ...) "summary"(object, ...) "summary"(object, ...) "print"(x, ...) "print"(x, ...) "print"(x, ...)

Arguments

object
an object of class "MCepi", "optvac", or "epiman" that must be named object for the generic methods summary
x
an object of class "MCepi", "optvac", or "epiman" that must be named x for generic printing and plotting via print
...
passed to the generic print or summary commands

Value

The summary commands documented here return a list containing (a subset of) the items below. The other functions do not return values.
obj
a copy of the input object
final
in the case of "MCepi"-class object this is a data.frame containing a summary of the distribution of the total number of vaccinations and the final cost; for "epiman"-class objects the distributional information is replaced by a scalar
params
in the case of "epiman"-class objects this data.frame containing a summary of the distributional information of SIR model parameters obtained during the final time step of the epidemic
best
the best policy contained in the "optvac"-class object
worst
the worst policy contained in the "optvac"-class object

Details

The printing and summaries provided by these functions are essentially identical except that summary returns a list that allows the information to be extracted for external use (in code) whereas the printing adds some additional text for human consumption including information about the call

Other ways of extracting information contained in these objects include the functions getvac, getcost, and getpolicy. The plotting functions plot.MCepi, plot.optvac, and plot.epiman are also helpful The list(s) returned by the summary command are detailed in the value section below

References

D. Merl, L.R. Johnson, R.B. Gramacy, and M.S. Mangel (2010). “amei: An R Package for the Adaptive Management of Epidemiological Interventions”. Journal of Statistical Software 36(6), 1-32. http://www.jstatsoft.org/v36/i06/ D. Merl, L.R. Johnson, R.B. Gramacy, M.S. Mangel (2009). “A Statistical Framework for the Adaptive Management of Epidemiological Interventions”. PLoS ONE, 4(6), e5807. http://www.plosone.org/article/info:doi/10.1371/journal.pone.0005807

See Also

MCepi, optvac, manage, MCmanage, getvac, getcost, getpolicy, plot.MCepi, plot.optvac, plot.epiman