"MCepi", "optvac",
"epiman". In the current version the printing
and summary commands are very similar
"print"(x, ...)
"print"(x, ...)
"print"(x, ...)
"summary"(object, ...)
"summary"(object, ...)
"summary"(object, ...)
"print"(x, ...)
"print"(x, ...)
"print"(x, ...)"MCepi", "optvac", or
"epiman" that must be named
object for the generic methods summary "MCepi", "optvac", or
"epiman" that must be named x for generic printing
and plotting via print summary commands documented here return
a list containing (a subset of) the items below.
The other functions do not return values."MCepi"-class object this
is a data.frame containing a summary of the distribution
of the total number of vaccinations and the final cost; for
"epiman"-class objects the distributional information
is replaced by a scalar "epiman"-class objects
this data.frame containing a summary of the distributional
information of SIR model parameters obtained during the final
time step of the epidemic "optvac"-class
object "optvac"-class
object summary returns a list
that allows the information to be extracted for external use
(in code) whereas the printing adds some additional text for
human consumption including information about the call Other ways of extracting information contained in these objects
include the functions getvac, getcost,
and getpolicy. The plotting functions
plot.MCepi, plot.optvac,
and plot.epiman are also helpful
The list(s) returned by the summary command are
detailed in the value section below
MCepi, optvac,
manage, MCmanage,
getvac, getcost, getpolicy,
plot.MCepi, plot.optvac,
plot.epiman